@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-logger
 version: 2.2.4.1
-id: wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
-key: wailo_1iM7IWzIYxc5wCErcOUTpR
+id: wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
+key: wailo_LehKhwfMAzKAYIng6nj4Ez
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: A logging system for WAI
@@ -20,7 +20,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
-hs-libraries: HSwai-logger-2.2.4.1-1iM7IWzIYxc5wCErcOUTpR
+hs-libraries: HSwai-logger-2.2.4.1-LehKhwfMAzKAYIng6nj4Ez
 depends:
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -34,7 +34,7 @@ depends:
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
 haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
 haddock-html: /usr/share/doc/haskell-wai-logger/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
